@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: options.cc,v 1.37 2008/09/02 05:04:45 lav Exp $ */
+/* $Id: options.cc,v 1.39 2009/05/22 06:21:06 lav Exp $ */
 
 #include <config.h>
 #include <ctype.h>
@@ -269,6 +269,12 @@ const struct init colors[]=
    { "syntax2_bw",	STR,  color_descriptions[SYNTAX2+MAX_COLOR_NO]	   },
    { "syntax3",		STR,  color_descriptions[SYNTAX3]		   },
    { "syntax3_bw",	STR,  color_descriptions[SYNTAX3+MAX_COLOR_NO]	   },
+   { "syntax4",		STR,  color_descriptions[SYNTAX4]		   },
+   { "syntax4_bw",	STR,  color_descriptions[SYNTAX4+MAX_COLOR_NO]	   },
+   { "syntax5",		STR,  color_descriptions[SYNTAX5]		   },
+   { "syntax5_bw",	STR,  color_descriptions[SYNTAX5+MAX_COLOR_NO]	   },
+   { "syntax6",		STR,  color_descriptions[SYNTAX6]		   },
+   { "syntax6_bw",	STR,  color_descriptions[SYNTAX6+MAX_COLOR_NO]	   },
    { "highlight",	STR,  color_descriptions[HIGHLIGHT]		   },
    { "highlight_bw",	STR,  color_descriptions[HIGHLIGHT+MAX_COLOR_NO]   },
    { NULL }
@@ -1231,7 +1237,7 @@ int ColorHandleBut(const char *button,int index)
    static int color_xlat[]={
       NORMAL_TEXT,BLOCK_TEXT,STATUS_LINE,SCROLL_BAR,ERROR_WIN,VERIFY_WIN,
       HELP_WIN,DIALOGUE_WIN,MENU_WIN,CURR_BUTTON,DISABLED_ITEM,SHADOWED,
-      SYNTAX1,SYNTAX2,SYNTAX3};
+      SYNTAX1,SYNTAX2,SYNTAX3,SYNTAX4,SYNTAX5,SYNTAX6};
    if(index<(int)(sizeof(color_xlat)/sizeof(*color_xlat)))
    {
       int color_no=color_xlat[index];
@@ -1263,32 +1269,22 @@ void  ColorsOpt()
    memcpy(new_bw_pal,bw_pal,sizeof(new_bw_pal));
 
    static struct opt m[]={
-      {" Normal text                        ",BUTTON,NULL,2,2},
-      {" Block text                         ",BUTTON,NULL,2,3},
-      {" Status line                        ",BUTTON,NULL,2,4},
-      {" Scroll bar                         ",BUTTON,NULL,2,5},
-      {" Error window                       ",BUTTON,NULL,2,6},
-      {" Verify window                      ",BUTTON,NULL,2,7},
-      {" Help window                        ",BUTTON,NULL,2,8},
-      {" Dialogue window                    ",BUTTON,NULL,2,9},
-      {" Menu                               ",BUTTON,NULL,2,10},
-      {" Current button                     ",BUTTON,NULL,2,11},
-      {" Disabled button                    ",BUTTON,NULL,2,12},
-      {" Shadow                             ",BUTTON,NULL,2,13},
-      {" Syntax 1                           ",BUTTON,NULL,2,14},
-      {" Syntax 2                           ",BUTTON,NULL,2,15},
-      {" Syntax 3                           ",BUTTON,NULL,2,16},
-//       {"[&Save]",			      BUTTON,NULL,MIDDLE-15,FDOWN-2},
-//       {"[Save for &tty]",                     BUTTON,NULL,MIDDLE-4, FDOWN-2},
-//       {"[&Use]",                              BUTTON,NULL,MIDDLE+7, FDOWN-2},
-//       {"[&Cancel]",			      BUTTON,NULL,MIDDLE+14,FDOWN-2},
+      {" Normal text      ",BUTTON,NULL,2,2},{" Block text       ",BUTTON,NULL,22,2},
+      {" Status line      ",BUTTON,NULL,2,3},{" Scroll bar       ",BUTTON,NULL,22,3},
+      {" Error window     ",BUTTON,NULL,2,4},{" Verify window    ",BUTTON,NULL,22,4},
+      {" Help window      ",BUTTON,NULL,2,5},{" Dialogue window  ",BUTTON,NULL,22,5},
+      {" Menu             ",BUTTON,NULL,2,6},{" Current button   ",BUTTON,NULL,22,6},
+      {" Disabled button  ",BUTTON,NULL,2,7},{" Shadow           ",BUTTON,NULL,22,7},
+      {" Syntax 1         ",BUTTON,NULL,2,8},{" Syntax 2         ",BUTTON,NULL,22,8},
+      {" Syntax 3         ",BUTTON,NULL,2,9},{" Syntax 4         ",BUTTON,NULL,22,9},
+      {" Syntax 5         ",BUTTON,NULL,2,10},{" Syntax 6         ",BUTTON,NULL,22,10},
       {"[   &Ok   ]",                         BUTTON,NULL,MIDDLE-8,FDOWN-2},
       {"[ &Cancel ]",			      BUTTON,NULL,MIDDLE+8,FDOWN-2},
       {NULL}};
 
    color_applied=false;
 
-   Dialogue(m,40,21," Select color to tune ",NULL,NULL,TOEatKey,ColorHandleBut);
+   Dialogue(m,42,15," Select color to tune ",NULL,NULL,TOEatKey,ColorHandleBut);
 
    if(color_applied)
    {
